@@ -1684,7 +1684,16 @@ class PatientFHIR(BaseFHIR):
         hn = self.given_family_to_human_name(given_name=mother_given_name, family_name=mother_family_name)
         contact.name = hn
         mother_codable_concept = CodeableConcept()
-        mother_codable_concept.coding = [Coding(jsondict={"system": mother_coding_system,"version": mother_coding_version,"code": "MERE"})]
+        mother_codable_concept.coding = [
+            Coding(
+                jsondict={
+                    "system": mother_coding_system,
+                    "version": mother_coding_version,
+                    "code": "MERE",
+                    "display": "Mère"
+                    }
+                )
+            ]
         contact.relationship = [mother_codable_concept]
         if patient.contact is None:
             patient.contact = [contact]
@@ -1738,7 +1747,16 @@ class PatientFHIR(BaseFHIR):
         hn = self.given_family_to_human_name(given_name=father_given_name, family_name=father_family_name)
         contact.name = hn
         father_codable_concept = CodeableConcept()
-        father_codable_concept.coding = [Coding(jsondict={"system": father_coding_system,"version": father_coding_version,"code": "PERE"})]
+        father_codable_concept.coding = [
+            Coding(
+                jsondict={
+                    "system": father_coding_system,
+                    "version": father_coding_version,
+                    "code": "PERE",
+                    "display": "Père"
+                    }
+                )
+            ]
         contact.relationship = [father_codable_concept]
         if patient.contact is None:
             patient.contact = [contact]
